# Pytorch Layers for Economics Applications

[![image](https://img.shields.io/pypi/v/econ_layers.svg)](https://pypi.python.org/pypi/econ_layers) [![Build Status](https://github.com/HighDimensionalEconLab/econ_layers/workflows/build/badge.svg)](https://github.com/HighDimensionalEconLab/econ_layers/actions)

## Pytorch 


-   Documentation: https://HighDimensionalEconLab.github.io/econ_layers

## Features

- Exponential layer
- Flexible multi-layer neural network with optional nonlinear last layer

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
